pub struct EntryRegistry { /* private fields */ }Expand description
Collects modules and registers plugins for an application entry.
Implementations
Sourceimpl EntryRegistry
impl EntryRegistry
Sourcepub fn add_module(&mut self, module: impl RenderModule + 'static)
pub fn add_module(&mut self, module: impl RenderModule + 'static)
Adds a render module to the entry registry.
Sourcepub fn register_plugin<P: Plugin>(&mut self, plugin: P)
pub fn register_plugin<P: Plugin>(&mut self, plugin: P)
Registers a plugin instance with the global plugin registry.
Sourcepub fn register_plugin_boxed<P: Plugin>(&mut self, plugin: Arc<RwLock<P>>)
pub fn register_plugin_boxed<P: Plugin>(&mut self, plugin: Arc<RwLock<P>>)
Registers a boxed plugin instance with the global plugin registry.
Sourcepub fn register_package<P: TesseraPackage>(&mut self, package: P)
pub fn register_package<P: TesseraPackage>(&mut self, package: P)
Registers a package into the entry registry.
Sourcepub fn finish(self) -> Vec<Box<dyn RenderModule>>
pub fn finish(self) -> Vec<Box<dyn RenderModule>>
Finalizes the registry into a module list for the renderer.